# Testes unitários do Texto-Transformer

Foram realizados testes unitários com unittest dos modelos AlbertModel, BertModel DistilBertModel, GPT2Model, OpenAIGPTModel, RobertaModel, XLMRoberta e XLNetModel.
